@@ -1,28 +1,9 @@
 /*
  * articlematcher.cpp
  *
- * Copyright (c) 2004, 2005 Frerich Raabe <raabe@kde.org>
+ * SPDX-FileCopyrightText: 2004, 2005 Frerich Raabe <raabe@kde.org>
  *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in the
- *    documentation and/or other materials provided with the distribution.
- *
- * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
- * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
- * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
- * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
- * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
- * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+ * SPDX-License-Identifier: BSD-2-Clause
  */
 #include "articlematcher.h"
 #include "article.h"
@@ -32,7 +13,7 @@
 #include <KConfigGroup>
 #include "akregator_debug.h"
 
-#include <QRegExp>
+#include <QRegularExpression>
 
 namespace Akregator {
 namespace Filters {
@@ -178,7 +159,7 @@ bool Criterion::satisfiedBy(const Article &article) const
 
     bool satisfied = false;
 
-    const Predicate predicateType = static_cast<Predicate>(m_predicate & ~Negation);
+    const auto predicateType = static_cast<Predicate>(m_predicate & ~Negation);
     QString subjectType = QLatin1String(concreteSubject.typeName());
 
     switch (predicateType) {
@@ -193,7 +174,7 @@ bool Criterion::satisfiedBy(const Article &article) const
         }
         break;
     case Matches:
-        satisfied = QRegExp(m_object.toString()).indexIn(concreteSubject.toString()) != -1;
+        satisfied = concreteSubject.toString().contains(QRegularExpression(m_object.toString()));
         break;
     default:
         qCDebug(AKREGATOR_LOG) << "Internal inconsistency; predicateType should never be Negation";
@@ -284,8 +265,8 @@ void ArticleMatcher::readConfig(KConfigGroup *config)
 
 bool ArticleMatcher::operator==(const AbstractMatcher &other) const
 {
-    AbstractMatcher *ptr = const_cast<AbstractMatcher *>(&other);
-    ArticleMatcher *o = dynamic_cast<ArticleMatcher *>(ptr);
+    auto *ptr = const_cast<AbstractMatcher *>(&other);
+    auto *o = dynamic_cast<ArticleMatcher *>(ptr);
     if (!o) {
         return false;
     } else {
