@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #ifndef WEBENGINEFRAME_H
@@ -27,17 +14,17 @@ class KActionCollection;
 
 namespace Akregator {
 class ArticleViewerWebEngineWidgetNg;
-class AKREGATORPART_EXPORT WebEngineFrame : public Frame
+class AKREGATOR_EXPORT WebEngineFrame : public Frame
 {
     Q_OBJECT
 public:
     explicit WebEngineFrame(KActionCollection *ac, QWidget *parent = nullptr);
     ~WebEngineFrame() override;
 
-    QUrl url() const override;
-    bool openUrl(const OpenUrlRequest &request) override;
+    Q_REQUIRED_RESULT QUrl url() const override;
+    Q_REQUIRED_RESULT bool openUrl(const OpenUrlRequest &request) override;
     void loadConfig(const KConfigGroup &, const QString &) override;
-    bool saveConfig(KConfigGroup &, const QString &) override;
+    Q_REQUIRED_RESULT bool saveConfig(KConfigGroup &, const QString &) override;
 
     Q_REQUIRED_RESULT qreal zoomFactor() const override;
 
