@@ -1,38 +1,20 @@
 /*
     This file is part of Akregator.
 
-    Copyright (C) 2005 Frank Osterfeld <osterfeld@kde.org>
+    SPDX-FileCopyrightText: 2005 Frank Osterfeld <osterfeld@kde.org>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-    As a special exception, permission is given to link this program
-    with any edition of Qt, and distribute the resulting executable,
-    without including the source code for Qt in the source distribution.
+    SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #include "searchbar.h"
 #include "akregatorconfig.h"
 
 #include "article.h"
-#include "widgets/statussearchline.h"
 
 #include <KLineEdit>
 #include <KLocalizedString>
 
 #include <QString>
-#include <QTimer>
 #include <QStandardPaths>
 #include <QHBoxLayout>
 
@@ -43,7 +25,7 @@ SearchBar::SearchBar(QWidget *parent)
     : QWidget(parent)
 {
     m_delay = 400;
-    QHBoxLayout *layout = new QHBoxLayout(this);
+    auto *layout = new QHBoxLayout(this);
 
     layout->setContentsMargins(2, 2, 2, 2);
     layout->setSpacing(5);
