@@ -1,26 +1,12 @@
 /*
-   Copyright (C) 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "statussearchline.h"
 #include <KLocalizedString>
 #include <QAction>
-#include <QIcon>
 #include <QKeyEvent>
 #include <QMenu>
 
@@ -79,10 +65,10 @@ void StatusSearchLine::initializeActions()
 void StatusSearchLine::showMenu()
 {
     QMenu p(this);
-    QActionGroup *grp = new QActionGroup(this);
+    auto *grp = new QActionGroup(this);
     grp->setExclusive(true);
     for (int i = AllArticles; i <= ImportantArticles; ++i) {
-        StatusSearchLine::Status status = static_cast<StatusSearchLine::Status>(i);
+        auto status = static_cast<StatusSearchLine::Status>(i);
         QAction *act = new QAction(mHashStatus.value(status).mIcon, mHashStatus.value(status).mText, this);
         act->setCheckable(true);
         act->setChecked(mDefaultStatus == status);
@@ -95,7 +81,7 @@ void StatusSearchLine::showMenu()
     }
     QAction *a = p.exec(mapToGlobal(QPoint(0, height())));
     if (a) {
-        const StatusSearchLine::Status newStatus = a->data().value<StatusSearchLine::Status>();
+        const auto newStatus = a->data().value<StatusSearchLine::Status>();
         updateStatusIcon(newStatus);
     }
 }
